Tests
=====

Cibyl tests cover the following:

  * unit: testing each component of the application
  * coverage: verify unit testing coverage is above 90%
  * e2e: testing as a user would experience it
  * linters: code analysis
  * docs: documentation testing

Each of the above can be executed with ``tox -e <type>`` or ``tox`` to run them all
